==> haskell-enclosed-exceptions-1.0.3-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.3
id: enclosed-exceptions-1.0.3-3oro4sEc5J67R9Jsi8HpNL
key: enclosed-exceptions-1.0.3-3oro4sEc5J67R9Jsi8HpNL
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
author: Michael Snoyman, João Cristóvão
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
abi: b73927c4543e9f1f5beaecd5e4bfe537
exposed: True
exposed-modules:
    Control.Exception.Enclosed
import-dirs: /usr/lib/ghc-8.6.4/site-local/enclosed-exceptions-1.0.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/enclosed-exceptions-1.0.3
hs-libraries: HSenclosed-exceptions-1.0.3-3oro4sEc5J67R9Jsi8HpNL
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    lifted-base-0.2.3.12-LbfKYhYt8PAHNw3WqlwSFn
    monad-control-1.0.2.3-3fyG0gh4gjL4D9yi94eZx transformers-0.5.6.2
    transformers-base-0.4.5.2-LOZfHxBYQIt6vOmm2orzyE
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.3-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.3
id: enclosed-exceptions-1.0.3-HXrVPoRvo2O5mUfFUokSFQ
key: enclosed-exceptions-1.0.3-HXrVPoRvo2O5mUfFUokSFQ
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
author: Michael Snoyman, João Cristóvão
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
abi: 8617c530c4a7af95249b1cb6a2c10320
exposed: True
exposed-modules:
    Control.Exception.Enclosed
import-dirs: /usr/lib/ghc-8.6.4/site-local/enclosed-exceptions-1.0.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/enclosed-exceptions-1.0.3
hs-libraries: HSenclosed-exceptions-1.0.3-HXrVPoRvo2O5mUfFUokSFQ
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    lifted-base-0.2.3.12-2ShwptSsxKq67F0RHM1qfm
    monad-control-1.0.2.3-CbJ0M7iQh3tCaJfGqTvvKL transformers-0.5.6.2
    transformers-base-0.4.5.2-AYmaSZMrRmtI5aj5cOhHJQ
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
